@@ -6,8 +6,9 @@ import configparser
 import os
 import sys
 import logging
+import typing
 
-from . import backend
+from . import backend, credentials
 from .util import platform_ as platform
 from .backends import fail
 
@@ -26,11 +27,11 @@ def set_keyring(keyring):
     keyring.set_properties_from_env()
 
 
-def get_keyring():
+def get_keyring() -> backend.KeyringBackend:
     """Get current keyring backend."""
     if _keyring_backend is None:
         init_backend()
-    return _keyring_backend
+    return typing.cast(backend.KeyringBackend, _keyring_backend)
 
 
 def disable():
@@ -44,28 +45,30 @@ def disable():
         pass
     filename = os.path.join(root, 'keyringrc.cfg')
     if os.path.exists(filename):
-        msg = "Refusing to overwrite {filename}".format(**locals())
+        msg = f"Refusing to overwrite {filename}"
         raise RuntimeError(msg)
     with open(filename, 'w') as file:
         file.write('[backend]\ndefault-keyring=keyring.backends.null.Keyring')
 
 
-def get_password(service_name, username):
+def get_password(service_name: str, username: str) -> typing.Optional[str]:
     """Get password from the specified service."""
     return get_keyring().get_password(service_name, username)
 
 
-def set_password(service_name, username, password):
+def set_password(service_name: str, username: str, password: str) -> None:
     """Set password for the user in the specified service."""
     get_keyring().set_password(service_name, username, password)
 
 
-def delete_password(service_name, username):
+def delete_password(service_name: str, username: str) -> None:
     """Delete the password for the user in the specified service."""
     get_keyring().delete_password(service_name, username)
 
 
-def get_credential(service_name, username):
+def get_credential(
+    service_name: str, username: typing.Optional[str]
+) -> typing.Optional[credentials.Credential]:
     """Get a Credential for the specified service."""
     return get_keyring().get_credential(service_name, username)
 
@@ -111,19 +114,12 @@ def _load_keyring_class(keyring_name):
 
     >>> popular_names = [
     ...      'keyring.backends.Windows.WinVaultKeyring',
-    ...      'keyring.backends.OS_X.Keyring',
+    ...      'keyring.backends.macOS.Keyring',
     ...      'keyring.backends.kwallet.DBusKeyring',
     ...      'keyring.backends.SecretService.Keyring',
     ...  ]
     >>> list(map(_load_keyring_class, popular_names))
     [...]
-
-    These legacy names are retained for compatibility.
-
-    >>> legacy_names = [
-    ...  ]
-    >>> list(map(_load_keyring_class, legacy_names))
-    [...]
     """
     module_name, sep, class_name = keyring_name.rpartition('.')
     __import__(module_name)
